@@ -820,11 +820,12 @@ ctStanModelWriter <- function(ctm, gendata, extratforms,matsetup,savemodel=TRUE,
       
         statetf[whichequals(whenvecs[2],0,0)] = 
           parvectform(whichequals(whenvecs[2],0,0),state, 2, matsetup, matvalues, si, whenvecs[2]);
-
-        ',matcalcs('si',when=2, c(PARS=10),basemats=FALSE),' //initialise PARS first, and simple PARS before complex PARS
+          
+        //initialise PARS first, and simple PARS before complex PARS
+        if(statedep[10] || whenmat[10,2]) PARS=mcalc(PARS,indparams, statetf,{2}, 10, matsetup, matvalues, si); 
         ',simplifystanfunction(paste0(ctm$modelmats$calcs$PARS,';\n\n ',collapse=' '),simplify),'
-      
-        ',matcalcs('si',when=2, mats$driftcint,basemats=FALSE),'
+        if(statedep[3] || whenmat[3,2]) DRIFT=mcalc(DRIFT,indparams, statetf,{2}, 3, matsetup, matvalues, si); 
+        if(statedep[7] || whenmat[7,2]) CINT=mcalc(CINT,indparams, statetf,{2}, 7, matsetup, matvalues, si); 
         ',simplifystanfunction(paste0(ctm$modelmats$calcs$driftcint,';\n\n ',collapse=' '),simplify),'
       
       if(statei > 0) {
@@ -845,46 +846,7 @@ ctStanModelWriter <- function(ctm, gendata, extratforms,matsetup,savemodel=TRUE,
     ')
   }
   
-  finiteJy<-function(){
-    paste0('
-  {
-    int zeroint[1];
-    row_vector[nlatentpop] basestate = state;
-    zeroint[1] = 0;
-    for(statei in append_array(Jyfinite,zeroint)){ //if some finite differences to do, compute these first
-      state = basestate;
-      if(statei>0 && (dosmoother + intoverstates) > 0)  state[statei] += Jstep;
-      
-            
-        statetf[whichequals(whenvecs[4],0,0)] = 
-          parvectform( whichequals(whenvecs[4],0,0), state, 4, matsetup, matvalues, si, whenvecs[4]);
-          
-        ',matcalcs('si',when=4, c(PARS=10),basemats=FALSE),' //initialise PARS first, and simple PARS before complex PARS
-        ',simplifystanfunction(paste0(ctm$modelmats$calcs$PARS,';\n\n ',collapse=' '),simplify),'
-      
-        ',matcalcs('si',when=4, mats$measurement,basemats=FALSE),'
-        ',simplifystanfunction(paste0(ctm$modelmats$calcs$measurement,';\n\n ',collapse=' '),simplify),'
-        
-      if(statei > 0 && (intoverstates) > 0) {
-        Jy[o,statei] =  LAMBDA[o] * state[1:nlatent]\' + MANIFESTMEANS[o,1]; //compute new change
-        Jy[o1,statei] = to_vector(inv_logit(to_array_1d(Jy[o1,statei])));
-         if(verbose>1) print("Jy ",Jy);
-      }
-      if(statei==0){
-        syprior[o] = LAMBDA[o] * state[1:nlatent]\' + MANIFESTMEANS[o,1];
-        syprior[o1] = to_vector(inv_logit(to_array_1d( syprior[o1] )));
-        if(size(Jyfinite) ) { //only need these calcs if there are finite differences to do -- otherwise loop just performs system calcs.
-          if(verbose>1) print("syprior = ",syprior,"    Jyinit= ",Jy);
-          for(fi in Jyfinite){
-            Jy[o,fi] -= syprior[o];
-            Jy[o,fi] /= Jstep; //new - baseline change divided by stepsize
-          }
-        }
-      }
-    }
-    if(verbose>1) print("Jy ",Jy);
-  }')
-  }
+
   
   
   
@@ -1020,6 +982,8 @@ ctStanModelWriter <- function(ctm, gendata, extratforms,matsetup,savemodel=TRUE,
     //init other system matrices (already done PARS, redo t0means in case of PARS dependencies...)
    ',matcalcs('si',when=0,
      matrices = c(mats$base[!mats$base %in% c(1,10)],mats$jacobian),basemats=TRUE),'
+     
+    if(si==0 || whenmat[5,5] || whenmat[5,4] || statedep[5]) MANIFESTcov = sdcovsqrt2cov(MANIFESTVAR,choleskymats);
     
     if(verbose==2) print("DRIFT = ",DRIFT);
     if(verbose==2) print("indparams = ", indparams);
@@ -1064,9 +1028,7 @@ ctStanModelWriter <- function(ctm, gendata, extratforms,matsetup,savemodel=TRUE,
 //      }
 //    }
 //  }
-  
-  if(si==0 || statedep[5] || sum(whenmat[5,]) || sum(whenmat[32,])) MANIFESTcov = sdcovsqrt2cov(MANIFESTVAR,choleskymats);
-    
+
     //if(verbose>1) print("nl T0cov = ", T0cov, "   J0 = ", J0);
     //etacov = quad_form(T0cov, J0\'); //probably unneeded, inefficient
     etacov=T0cov;
@@ -1085,20 +1047,20 @@ if(verbose > 1) print ("below t0 row ", rowi);
           ',#simplestatedependencies(when=2,mlist=c(mats$driftcint,mats$diffusion,mats$jacobian[2])),' #now done inside finite diff loop
       finiteJ(),'
       
-      ',matcalcs('si',when=2, mats$diffusion,basemats=FALSE),'
+      if(statedep[4] || whenmat[4,2]) DIFFUSION=mcalc(DIFFUSION,indparams, statetf,{2}, 4, matsetup, matvalues, si); 
+      if(statedep[52] || whenmat[52,2]) JAx=mcalc(JAx,indparams, statetf,{2}, 52, matsetup, matvalues, si); 
       ',simplifystanfunction(paste0(ctm$modelmats$calcs$diffusion,';\n\n ',collapse=' '),simplify),'
-      if(si==0 ||statedep[4] || whenmat[4,2] || ( T0check >0 && whenmat[4,5])){
+      
+      if(si==0 ||statedep[4] || whenmat[4,2] || ( T0check ==1 && whenmat[4,5])){
         DIFFUSIONcov[derrind,derrind] = sdcovsqrt2cov(DIFFUSION[derrind,derrind],choleskymats);
         if(!continuoustime) discreteDIFFUSION=DIFFUSIONcov;
       }
       
         if(continuoustime){
         
-            if(si==0 || dtchange==1 || statedep[3]||statedep[4] || statedep[52] || //if first sub or changing every state
-              whenmat[3,2] || whenmat[4,2] ||
-              (T0check == 1 && (whenmat[3,5]+whenmat[4,5]) > 0)){ //or first time step of new sub with ind difs
+            if(si==0 || dtchange==1 || statedep[3]|| statedep[52] || whenmat[3,2] || //if first sub or changing every state
+              (T0check == 1 && whenmat[3,5])){ //or first time step of new sub with ind difs
               
-              if(difftype==0 || (statedep[3]==0 && statedep[4]==0)){
                 //discreteDRIFT = expm2(append_row(append_col(DRIFT[1:nlatent, 1:nlatent],CINT),nlplusonezerovec\') * dtsmall);
                 discreteDRIFT = expm2(DRIFT * dtsmall);
                 
@@ -1106,29 +1068,32 @@ if(verbose > 1) print ("below t0 row ", rowi);
                   eJAx =  expm2(JAx * dtsmall);
                 } else eJAx[1:nlatent, 1:nlatent] = discreteDRIFT;
                                
-                if(si==0 || statedep[4]||statedep[52]|| 
-                  (whenmat[4,2]+whenmat[3,2]) > 0 || 
-                  (T0check==1 && (whenmat[4,5] || whenmat[3,5]))){ //if first pass, state dependent, or individually varying drift / diffusion
-                  asymDIFFUSIONcov[derrind,derrind] = ksolve(JAx[derrind,derrind], DIFFUSIONcov[derrind,derrind],verbose);
-                }
-                discreteDIFFUSION[derrind,derrind] =  asymDIFFUSIONcov[derrind,derrind] - 
-                  quad_form_sym( asymDIFFUSIONcov[derrind,derrind], eJAx[derrind,derrind]\' );
-              }
+            if(si==0 || statedep[3] || statedep[4]||statedep[52]||  //if first pass or state dependent
+              whenmat[4,2] || whenmat[3,2] ||
+              (T0check == 1 && (whenmat[3,5]  || whenmat[4,5]))){ //or first time step of new sub with ind difs
+              asymDIFFUSIONcov[derrind,derrind] = ksolve(JAx[derrind,derrind], DIFFUSIONcov[derrind,derrind],verbose);
             }
             
-             for(li in 1:nlatent) if(is_nan(state[li]) || is_nan(sum(discreteDRIFT[li,]))) {
-             print("Possible time step problem? Intervals too large? Try reduce maxtimestep");
+            discreteDIFFUSION[derrind,derrind] =  asymDIFFUSIONcov[derrind,derrind] - 
+              quad_form_sym( asymDIFFUSIONcov[derrind,derrind], eJAx[derrind,derrind]\' );
+              
+            } //end discrete coef calcs
+            
+            for(li in 1:nlatent) if(is_nan(state[li]) || is_nan(sum(discreteDRIFT[li,]))) {
+            print("Possible time step problem? Intervals too large? Try reduce maxtimestep");
             }
+            
             state[1:nlatent] *= discreteDRIFT\'; // ???compute before new diffusion calcs
             
-            if(size(CINTnonzero)>0){
-              if(si==0 || dtchange==1 || statedep[3]|| statedep[7] || 
-                whenmat[3,2] || whenmat[7,2] || //if first sub or changing every state
-                (T0check == 1 && (whenmat[3,5]+whenmat[7,5]) > 0)){ //or first time step of new sub with ind difs
+            if(size(CINTnonzero)){
+            
+              if(si==0 || dtchange==1 || statedep[3]|| statedep[7] || whenmat[3,2] || whenmat[7,2] || // state depenency
+                (T0check == 1 && (whenmat[7,5] || whenmat[3,5]))){ //or ind difs
                 discreteCINT = (DRIFT \\ (discreteDRIFT-IIlatentpop[1:nlatent,1:nlatent])) * CINT[,1];
               }
-              state[1:nlatent] += discreteCINT\';
-            }
+              
+            state[1:nlatent] += discreteCINT\';
+            } // end cint section
             
             if(intoverstates==1 || dosmoother==1){
               etacov = quad_form_sym(makesym(etacov,verbose,1), eJAx\');
@@ -1136,19 +1101,19 @@ if(verbose > 1) print ("below t0 row ", rowi);
             }
               
             if(intstepi >= (dt-1e-10) && dosmoother) eJAxs[rowi,,] = expm2(JAx * dt); //save approximate exponentiated jacobian for smoothing
+        } // end continuous time section
+        
+        if(continuoustime==0){ 
+          if(dosmoother) eJAxs[rowi,,] = JAx;
+          if(intoverstates==1 || dosmoother==1){
+            etacov = quad_form_sym(makesym(etacov,verbose,1), JAx\');
+            etacov[ derrind, derrind ] += DIFFUSIONcov[ derrind, derrind ]; 
           }
-  
-          if(continuoustime==0){ 
-            if(dosmoother) eJAxs[rowi,,] = JAx;
-            if(intoverstates==1 || dosmoother==1){
-              etacov = quad_form_sym(makesym(etacov,verbose,1), JAx\');
-              etacov[ derrind, derrind ] += DIFFUSIONcov[ derrind, derrind ]; 
-            }
-            state[1:nlatent] *= DRIFT\';
-            state[CINTnonzero]+= CINT[CINTnonzero,1]\';
-            
-          }
-        }
+          state[1:nlatent] *= DRIFT\';
+          state[CINTnonzero]+= CINT[CINTnonzero,1]\';
+        } // end non continuous time coefs
+        
+        } // end time step loop
       } // end non linear time update
     
     if(ntdpred > 0) {
@@ -1159,10 +1124,14 @@ if(verbose > 1) print ("below t0 row ", rowi);
         statetf[whichequals(whenvecs[3],0,0)] = 
           parvectform( whichequals(whenvecs[3],0,0), state, 3, matsetup, matvalues, si, whenvecs[3]);
           
-        ',matcalcs('si',when=3, c(PARS=10),basemats=FALSE),' //initialise PARS first, and simple PARS before complex PARS
+        //initialise PARS first, and simple PARS before complex PARS
+        if(statedep[10] || whenmat[10,3]) PARS=mcalc(PARS,indparams, statetf,{3}, 10, matsetup, matvalues, si); 
         ',simplifystanfunction(paste0(ctm$modelmats$calcs$PARS,';\n\n ',collapse=' '),simplify),'
+        
       
-        ',matcalcs('si',when=3, mats$tdpred,basemats=FALSE),'
+        if(statedep[9] || whenmat[9,3]) TDPREDEFFECT=mcalc(TDPREDEFFECT,indparams, statetf,{3}, 9, matsetup, matvalues, si); 
+        if(statedep[53] || whenmat[53,3]) Jtd=mcalc(Jtd,indparams, statetf,{3}, 53, matsetup, matvalues, si); 
+
         ',simplifystanfunction(paste0(ctm$modelmats$calcs$tdpred,';\n\n ',collapse=' '),simplify),'
 
         state[1:nlatent] +=   (TDPREDEFFECT * tdpreds[rowi])\'; //tdpred effect only influences at observed time point','
@@ -1192,12 +1161,56 @@ if(verbose > 1){
   etab[1,rowi] = state\';
 }','
 
- if ((si==0 || nobs_y[rowi] > 0 || dosmoother)){ //do this section for 0th subject as well to init matrices
-    
-      ',finiteJy(),'
+//measurement update
+
+  if(si == 0 || nobs_y[rowi] > 0 || dosmoother){ //measurement init
+    int zeroint[1];
+    row_vector[nlatentpop] basestate = state;
+    zeroint[1] = 0;
+    for(statei in append_array(Jyfinite,zeroint)){ //if some finite differences to do, compute these first
+      state = basestate;
+      if(statei>0 && (dosmoother + intoverstates) > 0)  state[statei] += Jstep;
+      
+            
+        statetf[whichequals(whenvecs[4],0,0)] = 
+          parvectform( whichequals(whenvecs[4],0,0), state, 4, matsetup, matvalues, si, whenvecs[4]);
+          
+        //initialise PARS first, and simple PARS before complex PARS
+        if(statedep[10] || whenmat[10,4]) PARS=mcalc(PARS,indparams, statetf,{4}, 10, matsetup, matvalues, si); 
+        ',simplifystanfunction(paste0(ctm$modelmats$calcs$PARS,';\n\n ',collapse=' '),simplify),'
+        
+      
+        if(statedep[2] || whenmat[2,4]) LAMBDA=mcalc(LAMBDA,indparams, statetf,{4}, 2, matsetup, matvalues, si); 
+        if(statedep[5] || whenmat[5,4]) MANIFESTVAR=mcalc(MANIFESTVAR,indparams, statetf,{4}, 5, matsetup, matvalues, si); 
+        if(statedep[6] || whenmat[6,4]) MANIFESTMEANS=mcalc(MANIFESTMEANS,indparams, statetf,{4}, 6, matsetup, matvalues, si); 
+        if(statedep[54] || whenmat[54,4]) Jy=mcalc(Jy,indparams, statetf,{4}, 54, matsetup, matvalues, si); 
+
+        ',simplifystanfunction(paste0(ctm$modelmats$calcs$measurement,';\n\n ',collapse=' '),simplify),'
+        
+      if(statei > 0 && (intoverstates) > 0) {
+        Jy[o,statei] =  LAMBDA[o] * state[1:nlatent]\' + MANIFESTMEANS[o,1]; //compute new change
+        Jy[o1,statei] = to_vector(inv_logit(to_array_1d(Jy[o1,statei])));
+        if(verbose>1) print("Jy ",Jy);
+      }
+      if(statei==0){
+        syprior[o] = LAMBDA[o] * state[1:nlatent]\' + MANIFESTMEANS[o,1];
+        syprior[o1] = to_vector(inv_logit(to_array_1d( syprior[o1] )));
+        if(size(Jyfinite) ) { //only need these calcs if there are finite differences to do -- otherwise loop just performs system calcs.
+          if(verbose>1) print("syprior = ",syprior,"    Jyinit= ",Jy);
+          for(fi in Jyfinite){
+            Jy[o,fi] -= syprior[o];
+            Jy[o,fi] /= Jstep; //new - baseline change divided by stepsize
+          }
+        }
+      }
+    }
+    if(verbose>1) print("Jy ",Jy);
+  } //end measurement init
+      
+  if(statedep[5] || whenmat[5,4]) MANIFESTcov = sdcovsqrt2cov(MANIFESTVAR,choleskymats);
+
  
-   if(statedep[5] || whenmat[5,4]) MANIFESTcov = sdcovsqrt2cov(MANIFESTVAR,choleskymats);
-   if(si > 0 && dokalmanrows[rowi] ==1){   //if not just inits...
+  if(si > 0 && (nobs_y[rowi] > 0 || dosmoother)){   //if not just inits...
 
       if(intoverstates==1 || dosmoother==1) { //classic kalman
         ycov[o,o] = quad_form_sym(makesym(etacov,verbose,1), Jy[o,]\') + MANIFESTcov[o,o]; // previously shifted measurement error down, but reverted
@@ -1287,7 +1300,6 @@ if(verbose > 1){
       if(verbose > 1) print(llrow[rowi]);
       
     }//end si > 0 nobs > 0 section
-  } // end measurement init loop and dokalmanrows section here to collect matrices
     
   ',if(savemodel) '     // store system matrices
        
@@ -1773,7 +1785,6 @@ data {
   int nJyfinite;
   int Jyfinite[nJyfinite];
   int taylorheun;
-  int difftype;
   int popcovn;
   int llsinglerow;
   int laplaceprior[nparams];
